@@ -3,9 +3,9 @@ package App::renlikewd;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-11-16'; # DATE
+our $DATE = '2023-11-21'; # DATE
 our $DIST = 'App-renlikewd'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 1;
 # ABSTRACT: REName a file so it becomes LIKE the current (Working) Directory's name
@@ -22,7 +22,7 @@ App::renlikewd - REName a file so it becomes LIKE the current (Working) Director
 
 =head1 VERSION
 
-This document describes version 0.002 of App::renlikewd (from Perl distribution App-renlikewd), released on 2021-11-16.
+This document describes version 0.003 of App::renlikewd (from Perl distribution App-renlikewd), released on 2023-11-21.
 
 =head1 SYNOPSIS
 
@@ -61,13 +61,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2021 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
